<?php

if ( !defined( 'ABSPATH' ) ) exit;

class silent_warning_802_settings
{
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            __('Silent warning settings', 'silent-warning'), 
            'manage_options', 
            'silent-warning-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = silent_warning_802_get_options ( 'silent_warning_options' );
        ?>
        <div class="wrap">
            <h1><?php echo __('Silent warning settings', 'silent-warning');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'silent-warning-tab' ] ) ? $_GET[ 'silent-warning-tab' ] : 'readme';
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=silent-warning-setting-admin&silent-warning-tab=readme" class="nav-tab  <?php echo $active_tab == 'readme' ? 'nav-tab-active' : ''; ?>"><?php echo __('Using plugin', 'silent-warning');?></a>
                <a href="?page=silent-warning-setting-admin&silent-warning-tab=settings" class="nav-tab  <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php echo __('Plugin settings', 'silent-warning');?></a>
            </h2>

            <?php
                switch ($active_tab){ 

                    case 'settings':
                       
                        ?>
                        <form method="post" action="options.php">
                        <?php
                            // This prints out all hidden setting fields
                            settings_fields( 'silent_warning_option_main' );
                            do_settings_sections( 'silent-warning-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <?php
                        exit;

                    default: 
                        echo '<h3>' . __('Using title', 'silent-warning'). '</h3>';
                        $lang = get_bloginfo('language');
                        if (file_exists(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use-'.$lang.'.php')) {
                            include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use-'.$lang.'.php' );
                        } else {
                            include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use.php' );
                        }
                }
            ?>

        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {        
        register_setting(
            'silent_warning_option_main', // Option group
            'silent_warning_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'silent_warning_settings_main', // ID
            __('Silent warning Custom Settings', 'silent-warning'), // Title
            array( $this, 'print_section_info' ), // Callback
            'silent-warning-setting-admin' // Page
        );  

        add_settings_field(
            'to_admins', // ID
            __('Alert to admins', 'silent-warning'), // Title
            array( $this, 'to_admins_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'to_other', // ID
            __('Other address', 'silent-warning'), // Title
            array( $this, 'to_other_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'admin_count', // ID
            __('Admin(s) count', 'silent-warning'), // Title
            array( $this, 'admin_count_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'index_size', // ID
            __('/index.php size', 'silent-warning'), // Title
            array( $this, 'index_size_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'config_size', // ID
            __('/config.php size', 'silent-warning'), // Title
            array( $this, 'config_size_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'access_size', // ID
            __('/.htaccess size', 'silent-warning'), // Title
            array( $this, 'access_size_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );


        add_settings_field(
            'storage_limit', // ID
            __('Free storage limit', 'silent-warning'), // Title
            array( $this, 'storage_limit_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

        add_settings_field(
            'database_limit', // ID
            __('Database size limit', 'silent-warning'), // Title
            array( $this, 'database_limit_callback' ), // Callback
            'silent-warning-setting-admin', // Page
            'silent_warning_settings_main' // Section
        );

    }

    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['to_admins'] ) ) {
            $new_input['to_admins'] = 1;
        } else {
            $new_input['to_admins'] = 0;
        }
        if ( isset( $input['to_other'] ) ) {
            $new_input['to_other'] = trim( $input['to_other'] );
        }

        if ( isset( $input['admin_count'] ) ) {
            $new_input['admin_count'] = trim( $input['admin_count'] );
        }
        if ( isset( $input['index_size'] ) ) {
            $new_input['index_size'] = trim( $input['index_size'] );
        }
        if ( isset( $input['config_size'] ) ) {
            $new_input['config_size'] = trim( $input['config_size'] );
        }
        if ( isset( $input['access_size'] ) ) {
            $new_input['access_size'] = trim( $input['access_size'] );
        }
        if ( isset( $input['storage_limit'] ) ) {
            $new_input['storage_limit'] = trim( $input['storage_limit'] );
        }
        if ( isset( $input['database_limit'] ) ) {
            $new_input['database_limit'] = trim( $input['database_limit'] );
        }

    	$get_issues = get_transient( 'health-check-site-status-result' );
    	$issue_counts = array();
    	if ( false !== $get_issues ) { $issue_counts = json_decode( $get_issues, true ); }
    	if ( ! is_array( $issue_counts ) || ! $issue_counts ) {
    		$issue_counts = array(
    			'good'        => 0,
    			'recommended' => 0,
    			'critical'    => 0,
    		);
    	}
        $issues_total = $issue_counts['recommended'] + $issue_counts['critical'];
        $new_input['health'] = $issues_total;
        
        update_option('silent_warning_legend', array(0,0,0,0,'0000',0,0,0), true);
        
        return $new_input;
    }

    public function print_section_info()
    {
        print __('Settings description', 'silent-warning');
    }

    public function to_admins_callback()
    {
        if ($this->options['to_admins'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="statistics_report_to_admins" name="silent_warning_options[to_admins]" value="1" '.$checked.' />' .
            '<label for="statistics_report_to_admins"></label>' .
            '<small>'.__('Send alert to all administrators.', 'silent-warning').'</small>',
            isset( $this->options['to_admins'] ) ? esc_attr( $this->options['to_admins']) : ''
        );
    }

    public function to_other_callback()
    {
        printf(
            '<input type="text" name="silent_warning_options[to_other]" value="%s" />' .
            '<br /><small>'.__('Send alert to other recipients. List email addresses separated by commas.<br /><em>(If you leave blank, there will be no more recipients.)</em>', 'silent-warning').'</small>',
            isset( $this->options['to_other'] ) ? esc_attr( $this->options['to_other']) : ''
        );
    }


    public function admin_count_callback()
    {

        $user_count_data = count_users();
        $count = $user_count_data['avail_roles']['administrator'];
        
        if ($count != $this->options['admin_count']) {
            $title = __('<span style="color: red;">Different number! </span>Number of administrators currently:', 'silent-warning') . '&nbsp;' . $count;
        } else {
            $title = __('Same as the number of current administrators.', 'silent-warning');
        }
        
        printf(
            '<input type="number" name="silent_warning_options[admin_count]" value="%s"  min="0" max="99999" style="width: 60px;" />' .
            '<br /><small>'.$title.'</small>',
            isset( $this->options['admin_count'] ) ? esc_attr( $this->options['admin_count']) : ''
        );
    }

    public function index_size_callback()
    {
        $size = filesize( ABSPATH . 'index.php' );
        if ($size != $this->options['index_size']) {
            $title = __('<span style="color: red">Different size! </span>The current file size is:', 'silent-warning') . '&nbsp;' . $size;
        } else {
            $title = __('Same as the current size.', 'silent-warning');
        }
        
        printf(
            '<input type="number" name="silent_warning_options[index_size]" value="%s"  min="1" max="99999" style="width: 100px;" />' .
            '<br /><small>'.$title.'</small>',
            isset( $this->options['index_size'] ) ? esc_attr( $this->options['index_size']) : ''
        );
    }

    public function config_size_callback()
    {
        $size = filesize( ABSPATH . 'wp-config.php' );
        if ($size != $this->options['config_size']) {
            $title = __('<span style="color: red">Different size! </span>The current file size is:', 'silent-warning') . '&nbsp;' . $size;
        } else {
            $title = __('Same as the current size.', 'silent-warning');
        }

        printf(
            '<input type="number" name="silent_warning_options[config_size]" value="%s"  min="1" max="99999" style="width: 100px;" />' .
            '<br /><small>'.$title.'</small>',
            isset( $this->options['config_size'] ) ? esc_attr( $this->options['config_size']) : ''
        );
    }

    public function access_size_callback()
    {
        $size = filesize( ABSPATH . '.htaccess' );
        if ($size != $this->options['access_size']) {
            $title = __('<span style="color: red">Different size! </span>The current file size is:', 'silent-warning') . '&nbsp;' . $size;
        } else {
            $title = __('Same as the current size.', 'silent-warning');
        }

        printf(
            '<input type="number" name="silent_warning_options[access_size]" value="%s"  min="1" max="99999" style="width: 100px;" />' .
            '<br /><small>'.$title.'</small>',
            isset( $this->options['access_size'] ) ? esc_attr( $this->options['access_size']) : ''
        );
    }


    public function storage_limit_callback()
    {
        printf(
            '<input type="number" name="silent_warning_options[storage_limit]" value="%s"  min="1" max="99999" style="width: 60px;" />&nbsp;GB' .
            '<br /><small>'.__('Storage_limit description.', 'silent-warning').'</small>',
            isset( $this->options['storage_limit'] ) ? esc_attr( $this->options['storage_limit']) : ''
        );
    }

    public function database_limit_callback()
    {
        printf(
            '<input type="number" name="silent_warning_options[database_limit]" value="%s"  min="1" max="99999" style="width: 60px;" />&nbsp;MB' .
            '<br /><small>'.__('Set it to the value - <em>in MegaByte</em> - above which you want to be notified.', 'silent-warning').'</small>',
            isset( $this->options['database_limit'] ) ? esc_attr( $this->options['database_limit']) : ''
        );
    }


}
